@@ -1,4 +1,4 @@
-from .utils import process_results, create_material, find_bounding_box
+from .utils import create_material, diff_between_angles
 
 from .Geometry import Geometry
 from .Materials import Materials
@@ -9,5 +9,7 @@ from .Tally import (
     MeshTallies2D,
     MeshTally3D,
     MeshTallies3D,
+    TetMeshTally,
+    TetMeshTallies,
 )
 from .Settings import FusionSettings
